pub fn ghost_encode_with_quality(
image_bytes: &[u8],
message: &str,
passphrase: &str,
) -> Result<(Vec<u8>, EncodeQuality), StegoError>Expand description
Encode with Ghost mode and return the encode quality score.
pub fn ghost_encode_with_quality(
image_bytes: &[u8],
message: &str,
passphrase: &str,
) -> Result<(Vec<u8>, EncodeQuality), StegoError>Encode with Ghost mode and return the encode quality score.